{% load i18n %}

{% verbatim %}
<ul class="resource-list">
<li ng-repeat="profile in results">
  <div class="row">
    <div class="col-md-1 resource-thumbnail">
      <a href="{{ profile.profile_detail_url }}" ><img ng-src="{{ profile.avatar_100 }}"/></a>
    </div>
    <div class="col-md-10 resource-description">
      <h5>
        <i class="fa fa-user"></i> <a href="{{ profile.profile_detail_url }}">{{ profile.username }}</a>
        <a href="mailto:{{ profile.email }}" ng-if="profile.email != ''"><i class="fa fa-envelope-o"></i></a>
      </h5>
      <p>{{ profile.organization != '' ?  profile.organization : "No Organization Info" }}</p>
      <ul class="list-inline">
        <li>
          <a href="{{ profile.profile_detail_url }}?content=layers">
            <strong>{{ profile.layers_count }}</strong>
            <ng-pluralize count="profile.layers_count" when="{'1': 'Layer', 'other': 'Layers'}"></ng-pluralize>
          </a>
        </li>
        <li>
          <a href="{{ profile.profile_detail_url }}?content=maps">
            <strong>{{ profile.maps_count }}</strong>
            <ng-pluralize count="profile.maps_count" when="{'1': 'Map', 'other': 'Maps'}"></ng-pluralize>
          </a>
        </li>
        <li>
          <a href="{{ profile.profile_detail_url }}?content=documents">
            <strong>{{ profile.documents_count }}</strong>
            <ng-pluralize count="profile.documents_count" when="{'1': 'Document', 'other': 'Documents'}"></ng-pluralize>
          </a>
        </li>
      </ul>
    </div>
  </div>
</li>
</ul>
{% endverbatim %}