@brand-danger: #d9534f;
@brand-success: #3c763d;
@footer_size: 100px;
@text: 14px;
@small-text: @text - 1;
@navbar-logo: '../img/logo.png';

html, body {
    height: 100%;
}

.navbar-brand {
  background: url(@navbar-logo) no-repeat;
  margin-top: 10px;
  overflow: hidden;
  text-indent: -9999em;
  width: 140px;
  height: 30px;
}

.footer {
    border-top: 1px solid #cccccc;
    height: @footer_size;
    padding: 23px;
    background: #eee;
    margin-top: 10px;
}

#wrap {
    height: 100%;
    height: auto !important;
    height: 100%;
    padding: 10px 0 100px;
    margin-bottom:-@footer_size;
    min-height: 100%;
}

nav.filter h4 {
  border-radius: 3px;
}

nav.filter h4 a.toggle{
  text-decoration: none;
}

.jumbotron {
  height: 300px;
  padding: 40px;
  border-bottom: 1px solid #cccccc;
  box-shadow: 0 0 10px rgba(0,0,0,.35);
  background: url('../img/fire_background.png') no-repeat left bottom;
  background-size: cover;

  h1 {
    font-weight: 600;
  }

}

.dropdown-menu > li a {
display: block;
padding: 3px 20px;
clear: both;
font-weight: 400;
line-height: 1.42857143;
color: #333;
white-space: nowrap;
}

.dropdown-menu form {
  padding: inherit;
}

/* Profile */

.resource-list {
  list-style: none;

  > li {
    padding: 3px;
  }

  .resource-description {
    > h5 {
      margin: 2px;
    }
  }

  .resource-thumbnail {
    padding-left: 0px;
    padding-right:0px;
    max-widht: 100px;

    img {
      max-width: 50px;
      border-radius: 3px;
      margin-top: 3px;
    }

  }
}

.select2-container {
  width: 250px;
}

.small-text {
  font-size: @small-text;
}

.user-avatar img {
  border-radius: 3px;
}

/* Hacks */
input[value='Invite User'] {
  margin-top: 10px;
}

span[id^="error_"].help-inline {
  color: @brand-danger;
}

/* End Hacks */